@@ -21,13 +21,13 @@ _app_data_location = QtCore.QStandardPaths.writableLocation(QtCore.QStandardPath
 if os.name == 'nt': # if windows
     _app_data_location = _app_data_location.replace('/', '\\')
 
-_user_packages_location = os.path.join(_app_data_location, "user-packages-py{0}{1}".format(sys.version_info.major, sys.version_info.minor))
+user_packages_location = os.path.join(_app_data_location, "user-packages-py{0}{1}".format(sys.version_info.major, sys.version_info.minor))
 
-_installed_requirements_path = os.path.join(_user_packages_location, "installed_requirements.txt")
+_installed_requirements_path = os.path.join(user_packages_location, "installed_requirements.txt")
 
 def _mkdirs():
     Path(_app_data_location).mkdir(parents=True, exist_ok=True)
-    Path(_user_packages_location).mkdir(parents=True, exist_ok=True)
+    Path(user_packages_location).mkdir(parents=True, exist_ok=True)
 
 class _ProgressDialog(QtWidgets.QDialog):
     def __init__(self, _parent_window):
@@ -170,7 +170,7 @@ class _ProcessHandler(QtCore.QObject):
             return
 
         if (self.process_terminated):
-            print('...terminated by the user', file = sys.stderr, flush = True)
+            print('...terminated by the user', flush = True)
             self.on_pipeline_finished(1, QtCore.QProcess.ExitStatus.NormalExit)
             return
 
@@ -340,7 +340,7 @@ def pip_install(requirements_txt, *, reinstall = False, ask = True):
     requirements_file_name = "requirements.txt"
     if (script_name):
         requirements_file_name = "requirements_" + script_name + ".txt"
-    current_requirements_path = os.path.join(_user_packages_location, requirements_file_name)
+    current_requirements_path = os.path.join(user_packages_location, requirements_file_name)
     current_requirements_file = open(current_requirements_path, "w")
     current_requirements_file.write(requirements_txt)
     current_requirements_file.close()
@@ -351,7 +351,7 @@ def pip_install(requirements_txt, *, reinstall = False, ask = True):
         python_executable = os.path.join(sys.exec_prefix, 'python.exe')
 
     env = QtCore.QProcessEnvironment.systemEnvironment()
-    env.insert("PYTHONUSERBASE", _user_packages_location)
+    env.insert("PYTHONUSERBASE", user_packages_location)
 
     #q_pip_process = QtCore.QProcess()
     #q_pip_process.setProgram(python_executable)
